@@ -1,23 +1,40 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/*
+ *  gnome-canvas-hacktext.c: Hacktext item type for GnomeCanvas widget
+ *                           This is mainly used for gnome-print preview context
+ *
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public License
+ *  as published by the Free Software Foundation; either version 2 of
+ *  the License, or (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *  Authors:
+ *    Federico Mena <federico@nuclecu.unam.mx>
+ *    Raph Levien <raph@acm.org>
+ *    Lauris Kaplinski <lauris@helixcode.com>
+ *
+ *  Copyright (C) 1998-1999 The Free Software Foundation
+ *  Copyright (C) 2000-2002 Ximian Inc.
+ *
+ */
+
 #define __GNOME_CANVAS_HACKTEXT_C__
+#define noVERBOSE
 
 /*
- * Hacktext item type for GnomeCanvas widget
- *
- * This is mainly useful for gnome-print preview context.
- *
- * Copyright (C) 1998,1999 The Free Software Foundation
- * Copyright (C) 2000 Helix Code, Inc.
- *
- * Authors: Federico Mena <federico@nuclecu.unam.mx>
- *          Raph Levien <raph@acm.org>
- *          Lauris Kaplinski <lauris@helixcode.com>
- *
  * TODO:
  * - Clipping
  */
 
-#define noVERBOSE
-
 /* These includes are set up for standalone compile. If/when this codebase
    is integrated into libgnomeui, the includes will need to change. */
 #include <math.h>
@@ -32,7 +49,6 @@ enum {
 	ARG_TEXT,
 	ARG_GLYPHLIST,
 	ARG_FILL_COLOR,
-	ARG_FILL_COLOR_GDK,
 	ARG_FILL_COLOR_RGBA,
 	ARG_FONT,
 	ARG_X,
@@ -64,10 +80,7 @@ static GnomeCanvasItemClass *parent_class;
 
 struct _GnomeCanvasHacktextPriv {
 	GnomeFont * font;
-#if 0
-	GnomeFontFace * face;
-	GnomeRFont * rfont;
-#endif
+
 	GnomeGlyphList * glyphlist;
 	GnomePosGlyphList * pgl;
 	double affine[6]; /* the text to world transform (NB! mirrored Y) */
@@ -113,9 +126,6 @@ gnome_canvas_hacktext_class_init (GnomeCanvasHacktextClass *class)
 	gtk_object_add_arg_type ("GnomeCanvasHacktext::text", GTK_TYPE_STRING, GTK_ARG_READWRITE, ARG_TEXT);
 	gtk_object_add_arg_type ("GnomeCanvasHacktext::glyphlist", GTK_TYPE_POINTER, GTK_ARG_READWRITE, ARG_GLYPHLIST);
 	gtk_object_add_arg_type ("GnomeCanvasHacktext::fill_color", GTK_TYPE_STRING, GTK_ARG_WRITABLE, ARG_FILL_COLOR);
-#if 0
-	gtk_object_add_arg_type ("GnomeCanvasHacktext::fill_color_gdk", GTK_TYPE_GDK_COLOR, GTK_ARG_READWRITE, ARG_FILL_COLOR_GDK);
-#endif
 	gtk_object_add_arg_type ("GnomeCanvasHacktext::fill_color_rgba", GTK_TYPE_UINT, GTK_ARG_READWRITE, ARG_FILL_COLOR_RGBA);
 	gtk_object_add_arg_type ("GnomeCanvasHacktext::font", GTK_TYPE_OBJECT, GTK_ARG_READWRITE, ARG_FONT);
 	gtk_object_add_arg_type ("GnomeCanvasHacktext::x", GTK_TYPE_DOUBLE, GTK_ARG_READWRITE, ARG_X);
@@ -295,15 +305,6 @@ gnome_canvas_hacktext_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 		gnome_canvas_item_request_update (item);
 		break;
 
-	case ARG_FILL_COLOR_GDK:
-		bp->fill_set = TRUE;
-		bp->fill_pixel = ((GdkColor *) GTK_VALUE_BOXED (*arg))->pixel;
-#if 0
-		set_gc_foreground (bp->fill_gc, bp->fill_pixel);
-#endif
-		gnome_canvas_item_request_update (item);
-		break;
-
 	case ARG_FILL_COLOR_RGBA:
 		bp->fill_set = TRUE;
 		bp->fill_rgba = GTK_VALUE_UINT (*arg);
@@ -318,9 +319,6 @@ gnome_canvas_hacktext_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 		if (font) gnome_font_ref (font);
 		if (bp->priv->font) gnome_font_unref (bp->priv->font);
 		bp->priv->font = font;
-#if 0
-		bp->priv->face = (GnomeFontFace *) gnome_font_get_face (bp->priv->font);
-#endif
 		bp->size = gnome_font_get_size (bp->priv->font);
 		gnome_canvas_item_request_update (item);
 		break;
@@ -340,22 +338,6 @@ gnome_canvas_hacktext_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 	}
 }
 
-#if 0
-/* Allocates a GdkColor structure filled with the specified pixel, and puts it into the specified
- * arg for returning it in the get_arg method.
- */
-static void
-get_color_arg (GnomeCanvasHacktext *hacktext, gulong pixel, GtkArg *arg)
-{
-	GdkColor *color;
-
-	color = g_new (GdkColor, 1);
-	color->pixel = pixel;
-	gdk_color_context_query_color (hacktext->item.canvas->cc, color);
-	GTK_VALUE_BOXED (*arg) = color;
-}
-#endif
-
 static void
 gnome_canvas_hacktext_get_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 {
@@ -370,13 +352,6 @@ gnome_canvas_hacktext_get_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 		} else
 			GTK_VALUE_POINTER (*arg) = NULL;
 		break;
-
-	case ARG_FILL_COLOR_GDK:
-#if 0
-		get_color_arg (bp, bp->fill_pixel, arg);
-#endif
-		break;
-		
 	case ARG_FILL_COLOR_RGBA:
 		GTK_VALUE_UINT (*arg) = bp->fill_color;
 		break;
