@@ -40,7 +40,7 @@ typedef struct _GnomePrintPreview GnomePrintPreview;
 typedef struct _GnomePrintPreviewClass GnomePrintPreviewClass;
 
 #include <libgnomeprint/gnome-print-paper.h>
-#include <libgnomecanvas.h>
+#include <libgnomecanvas/libgnomecanvas.h>
 #include <libgnomeprint/gnome-print.h>
 
 GType gnome_print_preview_get_type  (void);
