@@ -17,8 +17,6 @@
 
 G_BEGIN_DECLS
 
-#include "gpa-widget.h"
-
 #define GPA_TYPE_PRINTER_SELECTOR (gpa_printer_selector_get_type ())
 #define GPA_PRINTER_SELECTOR(obj) (GTK_CHECK_CAST ((obj), GPA_TYPE_PRINTER_SELECTOR, GPAPrinterSelector))
 #define GPA_PRINTER_SELECTOR_CLASS(klass) (GTK_CHECK_CLASS_CAST ((klass), GPA_TYPE_PRINTER_SELECTOR, GPAPrinterSelectorClass))
@@ -28,11 +26,14 @@ G_BEGIN_DECLS
 typedef struct _GPAPrinterSelector GPAPrinterSelector;
 typedef struct _GPAPrinterSelectorClass GPAPrinterSelectorClass;
 
+#include <libgnomeprint/private/gpa-private.h>
+#include "gpa-widget.h"
+
 struct _GPAPrinterSelector {
 	GPAWidget widget;
-	GtkWidget *menu;
-	GPANode *printers;
-	GSList *printerlist;
+	GtkWidget *menu; /* Option menu */
+	GPANode *printers; /* <Printers> node */
+	GSList *printerlist; /* GSList of <Printer> nodes */
 };
 
 struct _GPAPrinterSelectorClass {
