@@ -17,8 +17,6 @@
 
 G_BEGIN_DECLS
 
-#include "gpa-widget.h"
-
 #define GPA_TYPE_SETTINGS_SELECTOR (gpa_settings_selector_get_type ())
 #define GPA_SETTINGS_SELECTOR(obj) (GTK_CHECK_CAST ((obj), GPA_TYPE_SETTINGS_SELECTOR, GPASettingsSelector))
 #define GPA_SETTINGS_SELECTOR_CLASS(klass) (GTK_CHECK_CLASS_CAST ((klass), GPA_TYPE_SETTINGS_SELECTOR, GPASettingsSelectorClass))
@@ -28,13 +26,15 @@ G_BEGIN_DECLS
 typedef struct _GPASettingsSelector GPASettingsSelector;
 typedef struct _GPASettingsSelectorClass GPASettingsSelectorClass;
 
+#include <libgnomeprint/private/gpa-private.h>
+#include "gpa-widget.h"
+
 struct _GPASettingsSelector {
 	GPAWidget widget;
 	GtkWidget *menu;
 
 	GPANode *printer;
 	GPANode *settings;
-	guint pmid, smid;
 
 	GSList *settingslist;
 };
