@@ -44,7 +44,7 @@ static void gpa_ts_menuitem_activate (GtkWidget *widget, gint index);
 static void gpa_ts_select_transport (GPATransportSelector *ts, const gchar *id);
 
 static GPAWidgetClass *parent_class;
-static gchar *deflabel = N_("Printer default location");
+static gchar *deflabel = N_("Default printer");
 
 GtkType
 gpa_transport_selector_get_type (void)
