@@ -28,12 +28,19 @@ G_BEGIN_DECLS
 typedef struct _GPATransportSelector GPATransportSelector;
 typedef struct _GPATransportSelectorClass GPATransportSelectorClass;
 
+#include <libgnomeprint/private/gpa-private.h>
+#include "gpa-widget.h"
+
 struct _GPATransportSelector {
 	GPAWidget widget;
 	GtkWidget *hbox;
 	GtkWidget *menu;
-	GtkWidget *entry;
-	GtkWidget *label;
+	GtkWidget *fentry;
+	GtkWidget *centry;
+	GtkWidget *rbhbox;
+	GtkWidget *rbdefault;
+	GtkWidget *rbother;
+	GtkWidget *rbentry;
 	GPANode *printer;
 	GSList *transportlist;
 };
